__version__ = '0.2.0'

__title__ = "objectrest"
__github_project_name__ = "objectrest"
__author__ = 'Nate Harris'
__author_email__ = 'n8gr8gbln@gmail.com'
__github_username__ = "nwithan8"
__copyright__ = "Copyright © 2021 - Nate Harris"
__license__ = 'GNU General Public License v3 (GPLv3)'
__description__ = "A Python package to handle REST API requests, JSON parsing, and pydantic object generation."
__keywords__ = ["API", "REST", "objects", "pydantic", "JSON", "requests", "OAuth2", "token"]